@@ -1,15 +1,14 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond import backend
+from trytond.i18n import gettext
 from trytond.model import ModelSQL, fields
-from trytond.pyson import Eval
+from trytond.model.exceptions import AccessError
+from trytond.pyson import Eval, If, Bool
 from trytond.pool import PoolMeta, Pool
 from trytond.tools.multivalue import migrate_property
 from trytond.modules.company.model import CompanyValueMixin
 
-__all__ = ['Configuration', 'ConfigurationAssetSequence',
-    'ConfigurationAssetDate', 'Move', 'Period', 'Journal']
-
 asset_bymonthday = fields.Selection([
         ('1', "First"),
         ('-1', "Last"),
@@ -120,6 +119,44 @@ class ConfigurationAssetDate(ModelSQL, CompanyValueMixin):
         return "12"
 
 
+def AccountTypeMixin(template=False):
+
+    class Mixin:
+        fixed_asset = fields.Boolean(
+            "Fixed Asset",
+            domain=[
+                If(Eval('statement') != 'balance',
+                    ('fixed_asset', '=', False), ()),
+                ],
+            states={
+                'invisible': ((Eval('statement') != 'balance')
+                    | ~Eval('assets', True)),
+                },
+            depends=['statement', 'assets'])
+    if not template:
+        for fname in dir(Mixin):
+            field = getattr(Mixin, fname)
+            if not isinstance(field, fields.Field):
+                continue
+            field.states['readonly'] = (
+                Bool(Eval('template', -1)) & ~Eval('template_override', False))
+    return Mixin
+
+
+class AccountTypeTemplate(AccountTypeMixin(template=True), metaclass=PoolMeta):
+    __name__ = 'account.account.type.template'
+
+    def _get_type_value(self, type=None):
+        values = super()._get_type_value(type=type)
+        if not type or type.fixed_asset != self.fixed_asset:
+            values['fixed_asset'] = self.fixed_asset
+        return values
+
+
+class AccountType(AccountTypeMixin(), metaclass=PoolMeta):
+    __name__ = 'account.account.type'
+
+
 class Move(metaclass=PoolMeta):
     __name__ = 'account.move'
 
@@ -134,14 +171,6 @@ class Move(metaclass=PoolMeta):
 class Period(metaclass=PoolMeta):
     __name__ = 'account.period'
 
-    @classmethod
-    def __setup__(cls):
-        super(Period, cls).__setup__()
-        cls._error_messages.update({
-            'running_assets_close': ('Some asset lines "%(names)s" are still '
-                'running for this period "%(period)s".'),
-            })
-
     def check_asset_line_running(self):
         """
         Check if it exist some asset lines without account move for the curent
@@ -151,7 +180,6 @@ class Period(metaclass=PoolMeta):
         Asset = pool.get('account.asset')
         assets = Asset.search([
             ('state', '=', 'running'),
-            ('company', '=', self.company.id),
             ('lines', 'where', [
                 ('date', '>=', self.start_date),
                 ('date', '<=', self.end_date),
@@ -162,10 +190,10 @@ class Period(metaclass=PoolMeta):
             names = ', '.join(a.rec_name for a in assets[:5])
             if len(assets) > 5:
                 names += '...'
-            self.raise_user_error('running_assets_close', {
-                    'period': self.rec_name,
-                    'names': names,
-                    })
+            raise AccessError(
+                gettext('account_asset.msg_asset_running_close_period',
+                    period=self.rec_name,
+                    assets=names))
 
     @classmethod
     def close(cls, periods):
